PERRY_CDOM_BASE_URL = "https://cdom.perryhome.it/CDomWS.svc/rests"

# GET
PERRY_CDOM_GET_INFO_URL = "ThermoregGetInfo"
PERRY_CDOM_SET_SEASON = "ThermoregSetSeason"
PERRY_CDOM_GET_PROFILE = "ThermoregGetProfiles"
PERRY_CDOM_GET_VALVE_INFO = "ThermoregGetValveInfo"
PERRY_CDOM_GET_VALVE_ALARMS = "ThermoregGetValveAlarms"

# SET
PERRY_CDOM_SET_ZONES_PARMS = "ThermoregSetZonesParms"
PERRY_CDOM_SET_WORKING_MODE = "ThermoregSetWorkingMode"
PERRY_CDOM_SET_PROFILE_SOURCE = "ThermoregSetProfilesSource"
PERRY_CDOM_SET_REQUEST = "GeneralSetRequest"
